@@ -1,4 +1,4 @@
-from lib import LabelizerBase, ZIDSConfig, SharedArtifacts
+from dsFramework import LabelizerBase, ZIDSConfig, SharedArtifacts
 
 
 class generatedClass(LabelizerBase):
